@@ -270,6 +270,9 @@ def error(msg):
 
 
 #=============================================================================
-main()
+if(len(sys.argv)==2 and sys.argv[-1]=="--selftest"):
+    pass #TODO implement selftest
+else:
+    main()
 
 #EOF
